document.addEventListener('DOMContentLoaded', function () {
    const versionElement = document.getElementById('version');
    if (versionElement) {
        versionElement.textContent = getExtensionVersion();
    }

    loadSites();

    loadCheckInterval();

    document.getElementById('decreaseInterval').addEventListener('click', () => updateInterval(-1));
    document.getElementById('increaseInterval').addEventListener('click', () => updateInterval(1));
    document.getElementById('checkInterval').addEventListener('change', function () {
        let value = parseInt(this.value);
        if (value < 1) value = 1;
        if (value > 60) value = 60;
        this.value = value;
        saveCheckInterval(value);
    });

    document.getElementById('addSite').addEventListener('click', addSite);
    document.getElementById('save').addEventListener('click', saveSites);
});

function getExtensionVersion() {
    return chrome.runtime.getManifest().version;
}

function loadSites() {
    chrome.storage.sync.get('sites', function (data) {
        const sites = data.sites || [];
        const container = document.getElementById('sitesContainer');
        container.innerHTML = `
            <table class="site-table">
                <thead>
                    <tr style="font-size:16px">
                        <th>סטטוס</th>
                        <th>שם האתר</th>
                        <th>דף הבית</th>
                        <th>פעולות</th>
                    </tr>
                </thead>
                <tbody id="siteTableBody"></tbody>
            </table>
        `;
        const tableBody = document.getElementById('siteTableBody');
        sites.forEach((site, index) => {
            const row = document.createElement('tr');
            row.innerHTML = `
                <td>
                    <label class="switch">
                        <input type="checkbox" id="site${index}" ${site.enabled ? 'checked' : ''}>
                        <span class="slider"></span>
                    </label>
                </td>
                <td style="font-size:20px">${site.name}</td>
                <td style="font-size:16px">
                    <a href="${site.url}" target="_blank" style="color: blue; text-decoration: none;">${site.url.replace(/^https?:\/\//, '')}</a>
                </td>
                <td>
                    <button class="remove" data-index="${index}" style="background: none; border: none; padding: 0;">
                        <img src="icons/trash-red.png" alt="הסר" style="width: 20px; height: 20px;" />
                    </button>
                </td>
            `;
            tableBody.appendChild(row);

            const checkbox = row.querySelector(`#site${index}`);
            checkbox.addEventListener('change', function () {
                updateSiteStatus(index, this.checked);
            });
        });
        document.querySelectorAll('.remove').forEach(button => {
            button.addEventListener('click', removeSite);
        });
    });
}

function updateSiteStatus(index, enabled) {
    chrome.storage.sync.get('sites', function (data) {
        const sites = data.sites || [];
        if (sites[index]) {
            sites[index].enabled = enabled;
            chrome.storage.sync.set({ sites }, function () {
                console.log(`Site ${index} status updated to ${enabled}`);
            });
        }
    });
}

function addSite() {
    const name = document.getElementById('newSiteName').value;
    const url = document.getElementById('newSiteUrl').value;
    if (name && url) {
        chrome.storage.sync.get('sites', function (data) {
            const sites = data.sites || [];
            sites.push({ name, url, enabled: true });
            chrome.storage.sync.set({ sites }, loadSites);
        });
        document.getElementById('newSiteName').value = '';
        document.getElementById('newSiteUrl').value = '';
    }
}

function removeSite(event) {
    const index = event.currentTarget.dataset.index;
    console.log(`remove site ${index}`);

    chrome.storage.sync.get('sites', function (data) {
        const sites = data.sites || [];
        sites.splice(index, 1);
        chrome.storage.sync.set({ sites }, loadSites);
    });
}


function saveSites() {
    chrome.storage.sync.get(['sites', 'checkIntervalMinutes'], function (data) {
        const sites = data.sites || [];
        const interval = document.getElementById('checkInterval').value;
        
        sites.forEach((site, index) => {
            site.enabled = document.getElementById(`site${index}`).checked;
        });
        
        chrome.storage.sync.set({ 
            sites: sites,
            checkIntervalMinutes: parseInt(interval)
        }, function () {
            alert('ההגדרות נשמרו בהצלחה!');
        });
    });
}



function loadCheckInterval() {
    chrome.storage.sync.get('checkIntervalMinutes', function(data) {
        const interval = data.checkIntervalMinutes || 5;
        document.getElementById('checkInterval').value = interval;
        // document.getElementById('intervalDisplay').textContent = interval;
    });
}

function updateInterval(change) {
    const input = document.getElementById('checkInterval');
    let value = parseInt(input.value) + change;
    
    value = Math.min(Math.max(value, 1), 60);
    
    input.value = value;
    // document.getElementById('intervalDisplay').textContent = value;
    saveCheckInterval(value);
}

function saveCheckInterval(interval) {
    chrome.storage.sync.set({ checkIntervalMinutes: interval }, function() {
        chrome.runtime.sendMessage({ 
            action: 'updateCheckInterval', 
            interval: interval 
        });
    });
}